@@ -23,28 +23,25 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 23897 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2009-12-23 19:02:12 -0600 (Wed, 23 Dec 2009) $
  */
 
 
-#ifndef _PCYPHER
-#define _PCYPHER
+#ifndef PTLIB_CYPHER_H
+#define PTLIB_CYPHER_H
 
 #ifdef P_USE_PRAGMA
 #pragma interface
 #endif
 
-#ifndef _PTLIB_H
-#include <ptlib.h>
-#endif
 
 /** This class is used to encode/decode data using the MIME standard base64
    encoding mechanism as defined in RFC1521.
 
    To encode a large block of data use the following seqeunce:
-\begin{verbatim}
+<code>
       PBase64 base;
       base.StartEncoding();
       while (Read(dataChunk)) {
@@ -52,20 +49,20 @@
         out << base.GetEncodedString();
       }
       out << base.CompleteEncoding();
-\end{verbatim}
+</code>
 
     if smaller blocks that fit easily in memory are to be encoded the
     #Encode()# functions can be used to everything in one go.
 
     To decode a large block of data use the following sequence:
-\begin{verbatim}
+<code>
 
       PBase64 base;
       base.StartDecoding();
       while (Read(str) && ProcessDecoding(str))
         Write(base.GetDecodedData());
       Write(base.GetDecodedData());
-\end{verbatim}
+</code>
 
     if smaller blocks that fit easily in memory are to be decoded the
     #Decode()# functions can be used to everything in one go.
@@ -810,7 +807,7 @@ class PSecureConfig : public PConfig
 
 #endif // P_CONFIG_FILE
 
-#endif // _PCYPHER
+#endif // PTLIB_CYPHER_H
 
 
 // End Of File ///////////////////////////////////////////////////////////////
