@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21788 $
+ * $Revision: 22915 $
  * $Author: rjongbloed $
- * $Date: 2008-12-11 23:42:13 -0600 (Thu, 11 Dec 2008) $
+ * $Date: 2009-06-17 23:13:31 -0500 (Wed, 17 Jun 2009) $
  */
 
 #ifndef PTLIB_HTTPSVC_H
@@ -332,10 +332,17 @@ class PServiceHTML : public PHTML
       NoURLOverride       = 4,
       NoSignatureForFile  = 8
     };
-    static PBoolean ProcessMacros(PHTTPRequest & request,
-                              PString & text,
-                              const PString & filename,
-                              unsigned options);
+    static bool ProcessMacros(
+      PHTTPRequest & request,
+      PString & text,
+      const PString & filename,
+      unsigned options
+    );
+    static bool SpliceMacro(
+      PString & text,
+      const PString & tokens,
+      const PString & value
+    );
 };
 
 
