@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21788 $
+ * $Revision: 23931 $
  * $Author: rjongbloed $
- * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
+ * $Date: 2010-01-13 06:19:08 -0600 (Wed, 13 Jan 2010) $
  */
 
 #ifndef PTLIB_PSOCKBUN_H
@@ -122,7 +122,7 @@ class PInterfaceMonitor : public PProcessStartup
     bool GetInterfaceInfo(
       const PString & iface,  /// Interface desciptor name
       InterfaceEntry & info   /// Information on the interface
-    );
+    ) const;
     
     /** Returns whether the descriptor string equals the interface entry.
         Note that when searching the descriptor may be a partial match
@@ -166,10 +166,9 @@ class PInterfaceMonitor : public PProcessStartup
     PTimeInterval  m_refreshInterval;
     PMutex         m_threadMutex;
     PThread      * m_updateThread;
-    PSyncPoint     m_signalUpdate;
-    bool           m_threadRunning;
-    
+
     PInterfaceFilter * m_interfaceFilter;
+    PIPSocket::RouteTableDetector * m_changedDetector;
 
   friend class PInterfaceMonitorClient;
 };
@@ -212,7 +211,7 @@ class PInterfaceMonitorClient : public PSafeObject
     virtual PBoolean GetInterfaceInfo(
       const PString & iface,  /// Interface desciptor name
       InterfaceEntry & info   /// Information on the interface
-    );
+    ) const;
     
     /**Returns the priority of this client. A higher value means higher priority.
        Higher priority clients get their callback functions called first. Clients
