@@ -26,11 +26,14 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 23897 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2009-12-23 19:02:12 -0600 (Wed, 23 Dec 2009) $
  */
 
+#ifndef PTLIB_LISTS_H
+#define PTLIB_LISTS_H
+
 #ifdef P_USE_PRAGMA
 #pragma interface
 #endif
@@ -45,6 +48,8 @@ struct PListElement
     PListElement * prev;
     PListElement * next;
     PObject * data;
+
+    PDECLARE_POOL_ALLOCATOR();
 };
 
 struct PListInfo
@@ -52,6 +57,8 @@ struct PListInfo
     PListInfo() { head = tail = NULL; }
     PListElement * head;
     PListElement * tail;
+
+    PDECLARE_POOL_ALLOCATOR();
 };
 
 /**This class is a collection of objects which are descendents of the
@@ -92,24 +99,23 @@ class PAbstractList : public PCollection
   // Overrides from class PObject
     /**Get the relative rank of the two lists. The following algorithm is
        employed for the comparison:
-\begin{description}
-       \item[#EqualTo#] if the two lists are identical in length
+
+       \arg \c EqualTo if the two lists are identical in length
        and each objects values, not pointer, are equal.
 
-       \item[#LessThan#] if the instances object value at an
+       \arg \c LessThan if the instances object value at an
        ordinal position is less than the corresponding objects value in the
        #obj# parameters list.
                           
        This is also returned if all objects are equal and the instances list
        length is less than the #obj# parameters list length.
 
-       \item[#GreaterThan#] if the instances object value at an
+       \arg \c GreaterThan if the instances object value at an
        ordinal position is greater than the corresponding objects value in the
        #obj# parameters list.
                           
        This is also returned if all objects are equal and the instances list
        length is greater than the #obj# parameters list length.
-\end{description}
 
        @return
        comparison of the two objects, #EqualTo# for same,
@@ -421,7 +427,7 @@ template <class T> class PList : public PAbstractList
 
 /**Declare a list class.
    This macro is used to declare a descendent of PAbstractList class,
-   customised for a particular object type {\bf T}. This macro closes the
+   customised for a particular object type <b>T</b>. This macro closes the
    class declaration off so no additional members can be added.
 
    If the compilation is using templates then this macro produces a typedef
@@ -434,7 +440,7 @@ template <class T> class PList : public PAbstractList
 
 /**Begin declaration of list class.
    This macro is used to declare a descendent of PAbstractList class,
-   customised for a particular object type {\bf T}.
+   customised for a particular object type <b>T</b>.
 
    If the compilation is using templates then this macro produces a descendent
    of the #PList# template class. If templates are not being used then the
@@ -461,7 +467,7 @@ template <class T> class PList : public PAbstractList
    queue. The functions in this class primarily do all the appropriate casting
    of types.
 
-   By default, objects placed into the set will {\bf not} be deleted when
+   By default, objects placed into the set will <b>T</b> be deleted when
    removed or when all references to the set are destroyed. This is different
    from the default on most collection classes.
 
@@ -477,7 +483,7 @@ template <class T> class PQueue : public PAbstractList
   //@{
     /**Create a new, empty, queue.
 
-       Note that by default, objects placed into the queue will {\bf not} be
+       Note that by default, objects placed into the queue will <b>not</b> be
        deleted when removed or when all references to the queue are destroyed.
        This is different from the default on most collection classes.
      */
@@ -520,7 +526,7 @@ template <class T> class PQueue : public PAbstractList
 
 /**Declare a queue class.
    This macro is used to declare a descendent of PAbstractList class,
-   customised for a particular object type {\bf T}, and adds functionality
+   customised for a particular object type <b>T</b>, and adds functionality
    that allows the list to be used as a first in first out queue. This macro
    closes the class declaration off so no additional members can be added.
 
@@ -535,7 +541,7 @@ template <class T> class PQueue : public PAbstractList
 
 /**Begin declataion of a queue class.
    This macro is used to declare a descendent of PAbstractList class,
-   customised for a particular object type {\bf T}, and adds functionality
+   customised for a particular object type <b>T</b>, and adds functionality
    that allows the list to be used as a first in first out queue.
 
    If the compilation is using templates then this macro produces a descendent
@@ -563,7 +569,7 @@ template <class T> class PQueue : public PAbstractList
    stack. The functions in this class primarily do all the appropriate casting
    of types.
 
-   By default, objects placed into the set will {\bf not} be deleted when
+   By default, objects placed into the set will <b>not</b> be deleted when
    removed or when all references to the set are destroyed. This is different
    from the default on most collection classes.
 
@@ -579,7 +585,7 @@ template <class T> class PStack : public PAbstractList
   //@{
     /**Create a new, empty, stack.
 
-       Note that by default, objects placed into the stack will {\bf not} be
+       Note that by default, objects placed into the stack will <b>not</b> be
        deleted when removed or when all references to the stack are destroyed.
        This is different from the default on most collection classes.
      */
@@ -633,7 +639,7 @@ template <class T> class PStack : public PAbstractList
 
 /**Declare a stack class.
    This macro is used to declare a descendent of PAbstractList class,
-   customised for a particular object type {\bf T}, and adds functionality
+   customised for a particular object type <b>T</b>, and adds functionality
    that allows the list to be used as a last in first out stack. This macro
    closes the class declaration off so no additional members can be added.
 
@@ -648,7 +654,7 @@ template <class T> class PStack : public PAbstractList
 
 /**Begin declaration of a stack class.
    This macro is used to declare a descendent of PAbstractList class,
-   customised for a particular object type {\bf T}, and adds functionality
+   customised for a particular object type <b>T</b>, and adds functionality
    that allows the list to be used as a last in first out stack.
 
    If the compilation is using templates then this macro produces a descendent
@@ -682,6 +688,8 @@ struct PSortedListElement
   PObject            * data;
   PINDEX               subTreeSize;
   enum { Red, Black }  colour;
+
+  PDECLARE_POOL_ALLOCATOR();
 };
 
 struct PSortedListInfo
@@ -698,6 +706,8 @@ struct PSortedListInfo
   PSortedListElement * OrderSelect(PSortedListElement * node, PINDEX index) const;
 
   typedef PSortedListElement Element;
+
+  PDECLARE_POOL_ALLOCATOR();
 };
 
 /**This class is a collection of objects which are descendents of the
@@ -745,24 +755,23 @@ class PAbstractSortedList : public PCollection
   //@{
     /**Get the relative rank of the two lists. The following algorithm is
        employed for the comparison:
-\begin{descriptions}
-       \item[#EqualTo#] if the two lists are identical in length
+
+       \arg \c EqualTo if the two lists are identical in length
        and each objects values, not pointer, are equal.
 
-       \item[#LessThan#] if the instances object value at an
+       \arg \c LessThan if the instances object value at an
        ordinal position is less than the corresponding objects value in the
        #obj# parameters list.
                           
        This is also returned if all objects are equal and the instances list
        length is less than the #obj# parameters list length.
 
-       \item[#GreaterThan#] if the instances object value at an
+       \arg \c GreaterThan if the instances object value at an
        ordinal position is greater than the corresponding objects value in the
        #obj# parameters list.
                           
        This is also returned if all objects are equal and the instances list
        length is greater than the #obj# parameters list length.
-\end{descriptions}
 
        @return
        comparison of the two objects, #EqualTo# for same,
@@ -988,7 +997,7 @@ template <class T> class PSortedList : public PAbstractSortedList
 
 /**Declare a sorted list class.
    This macro is used to declare a descendent of PAbstractSortedList class,
-   customised for a particular object type {\bf T}. This macro closes the
+   customised for a particular object type <b>T</b>. This macro closes the
    class declaration off so no additional members can be added.
 
    If the compilation is using templates then this macro produces a typedef
@@ -1002,7 +1011,7 @@ template <class T> class PSortedList : public PAbstractSortedList
 
 /**Begin declaration of a sorted list class.
    This macro is used to declare a descendent of PAbstractSortedList class,
-   customised for a particular object type {\bf T}.
+   customised for a particular object type <b>T</b>.
 
    If the compilation is using templates then this macro produces a descendent
    of the #PSortedList# template class. If templates are not being used
@@ -1025,4 +1034,7 @@ template <class T> class PSortedList : public PAbstractSortedList
       { return PNEW cls(0, this); } \
 
 
+#endif // PTLIB_LISTS_H
+
+
 // End Of File ///////////////////////////////////////////////////////////////
