@@ -7,13 +7,13 @@
  *
  * Contributor(s): Snark at GnomeMeeting
  *
- * $Revision: 20850 $
- * $Author: ms30002000 $
- * $Date: 2008-09-04 16:51:58 +0000 (Thu, 04 Sep 2008) $
+ * $Revision: 22443 $
+ * $Author: rjongbloed $
+ * $Date: 2009-04-20 18:47:22 -0500 (Mon, 20 Apr 2009) $
  */
 
-#ifndef _PLUGINMGR_H
-#define _PLUGINMGR_H
+#ifndef PTLIB_PLUGINMGR_H
+#define PTLIB_PLUGINMGR_H
 
 #define DEFAULT_PLUGINDIR "/usr/lib/pwlib"
 
@@ -137,7 +137,7 @@ class PPluginModuleManager : public PObject
   public:
     typedef PDictionary<PString, PDynaLink> PluginListType;
 
-    PPluginModuleManager(const char * _signatureFunctionName, PPluginManager * pluginMgr = NULL);
+    PPluginModuleManager(const char * signatureFunctionName, PPluginManager * pluginMgr = NULL);
 
     PBoolean LoadPlugin(const PString & fileName)
     { if (pluginMgr == NULL) return PFalse; else return pluginMgr->LoadPlugin(fileName); }
@@ -163,4 +163,11 @@ class PPluginModuleManager : public PObject
     PPluginManager * pluginMgr;
 };
 
-#endif // ifndef _PLUGINMGR_H
+
+PFACTORY_LOAD(PluginLoaderStartup);
+
+
+#endif // PTLIB_PLUGINMGR_H
+
+
+// End Of File ///////////////////////////////////////////////////////////////
