@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21788 $
+ * $Revision: 23897 $
  * $Author: rjongbloed $
- * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
+ * $Date: 2009-12-23 19:02:12 -0600 (Wed, 23 Dec 2009) $
  */
 
 #ifndef PTLIB_PROCESS_H
@@ -44,6 +44,7 @@
 #include <ptlib/pfactory.h>
 
 #include <queue>
+#include <set>
 
 /**Create a process.
    This macro is used to create the components necessary for a user PWLib
@@ -137,44 +138,74 @@ class PTimerList : public PObject
         enum Action {
           Stop,
           Start
-        } action;
+        } m_action;
 
         RequestType(Action act, PTimer * t)
-          : action(act)
-          , timer(t)
-          , id(timer->GetTimerId())
-          , sync(NULL)
+          : m_action(act)
+          , m_timer(t)
+          , m_id(t->GetTimerId())
+          , m_absoluteTime(t->GetAbsoluteTime())
+          , m_serialNumber(t->GetNextSerialNumber())
+          , m_sync(NULL)
         { }
 
-        PTimer * timer;
-        PTimer::IDType id;
-        PSyncPoint * sync;
+        PTimer *                    m_timer;
+        PTimer::IDType              m_id;
+        PInt64                      m_absoluteTime;
+        PAtomicInteger::IntegerType m_serialNumber;
+        PSyncPoint *                m_sync;
     };
 
     void QueueRequest(RequestType::Action action, PTimer * timer, bool isSync = true);
 
+    void ProcessTimerQueue();
+
   private:
+    // queue of timer action requests
+    PMutex m_queueMutex;
+    typedef std::queue<RequestType> RequestQueueType;
+    RequestQueueType m_requestQueue;
+
+    // add an active timer to the lists
+    void AddActiveTimer(const RequestType & request);
+
+    //  counter to keep track of timer IDs
     mutable PAtomicInteger timerId; 
 
-    // map used to store timer information
-    PMutex timerListMutex;
-    struct TimerInfoType {
-      TimerInfoType(PTimer * t) : timer(t)  { removed = false; }
-      PTimer * timer;
-      bool removed;
+    // map used to store active timer information
+    struct ActiveTimerInfo {
+      ActiveTimerInfo(PTimer * t, PAtomicInteger::IntegerType serialNumber) 
+        : m_timer(t), m_serialNumber(serialNumber) { }
+      PTimer * m_timer;
+      PAtomicInteger::IntegerType m_serialNumber;
     };
-    typedef std::map<PTimer::IDType, TimerInfoType> TimerInfoMapType;
-    TimerInfoMapType activeTimers;
-    PThread * timerThread;
+    typedef std::map<PTimer::IDType, ActiveTimerInfo> ActiveTimerInfoMap;
+    ActiveTimerInfoMap m_activeTimers;
 
-    // queue of timer action requests
-    PMutex queueMutex;
-    typedef std::queue<RequestType> RequestQueueType;
-    RequestQueueType requestQueue;
-    RequestQueueType addQueue;
+    // set used to store timer expiry times, in order
+    struct TimerExpiryInfo {
+      TimerExpiryInfo(PTimer::IDType id, PInt64 expireTime, PAtomicInteger::IntegerType serialNumber)
+        : m_timerId(id), m_expireTime(expireTime), m_serialNumber(serialNumber) { }
+      PTimer::IDType m_timerId;
+      PInt64 m_expireTime;
+      PAtomicInteger::IntegerType m_serialNumber;
+    };
+
+	  struct TimerExpiryInfo_compare
+		  : public binary_function<TimerExpiryInfo, TimerExpiryInfo, bool>
+	  {	
+	    bool operator()(const TimerExpiryInfo & _Left, const TimerExpiryInfo & _Right) const
+		  {	return (_Left.m_expireTime < _Right.m_expireTime); }
+	  };
+
+    typedef std::multiset<TimerExpiryInfo, TimerExpiryInfo_compare> TimerExpiryInfoList;
+    TimerExpiryInfoList m_expiryList;
 
     // The last system timer tick value that was used to process timers.
-    PTimeInterval lastSample;
+    PTimeInterval m_lastSample;
+
+    // thread that handles the timer stuff
+    PThread * m_timerThread;
 };
 
 
@@ -219,7 +250,8 @@ class PProcess : public PThread
       WORD majorVersion = 1,           ///< Major version number of the product
       WORD minorVersion = 0,           ///< Minor version number of the product
       CodeStatus status = ReleaseCode, ///< Development status of the product
-      WORD buildNumber = 1             ///< Build number of the product
+      WORD buildNumber = 1,            ///< Build number of the product
+      bool library = false             ///< PProcess is a library rather than an application
     );
   //@}
 
@@ -261,7 +293,7 @@ class PProcess : public PThread
 
   /**@name Process information functions */
   //@{
-    /**Get the current processes object instance. The {\it current process}
+    /**Get the current processes object instance. The <i>current process</i>
        is the one the application is running in.
        
        @return
@@ -293,7 +325,7 @@ class PProcess : public PThread
 
        Default behaviour returns false and the process is killed.
 
-       @Return true if the process is to be allowed to continue, false otherwise.
+       @return true if the process is to be allowed to continue, false otherwise.
       */
     virtual bool OnInterrupt(
       bool terminating ///< true if process terminating.
@@ -558,6 +590,14 @@ class PProcess : public PThread
        Directory for OS configuration files.
      */
     static PDirectory GetOSConfigDir();
+
+    /**Get the version of the PTLib library the process is running on, eg
+       "2.5beta3".
+       
+       @return
+       String for library version.
+     */
+    static PString GetLibVersion();
   //@}
 
     /**Get the list of timers handled by the application. This is an internal
@@ -684,8 +724,11 @@ class PProcess : public PThread
 
     bool m_library;
 
-    PDictionary<POrdinalKey, PThread> activeThreads;
-    PMutex                            activeThreadMutex;
+    bool m_shuttingDown;
+
+    typedef std::map<PThreadIdentifier, PThread *> ThreadMap;
+    ThreadMap m_activeThreads;
+    PMutex    m_activeThreadMutex;
     
   friend class PThread;
 
@@ -713,14 +756,11 @@ class PProcess : public PThread
     PLibraryProcess(
       const char * manuf = "",         ///< Name of manufacturer
       const char * name = "",          ///< Name of product
-      WORD majorVersion = 1,           ///< Major version number of the product
-      WORD minorVersion = 0,           ///< Minor version number of the product
-      CodeStatus status = ReleaseCode, ///< Development status of the product
-      WORD buildNumber = 1             ///< Build number of the product
-    ) : PProcess(manuf, name, majorVersion, minorVersion, status, buildNumber)
-    {
-      m_library = true;
-    }
+      WORD majorVersionNum = 1,           ///< Major version number of the product
+      WORD minorVersionNum = 0,           ///< Minor version number of the product
+      CodeStatus statusCode = ReleaseCode, ///< Development status of the product
+      WORD buildNum = 1             ///< Build number of the product
+    ) : PProcess(manuf, name, majorVersionNum, minorVersionNum, statusCode, buildNum, true) { }
   //@}
 
     ///< Dummy Main() as libraries do not have one.
