@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21788 $
+ * $Revision: 23897 $
  * $Author: rjongbloed $
- * $Date: 2008-12-12 05:42:13 +0000 (Fri, 12 Dec 2008) $
+ * $Date: 2009-12-23 19:02:12 -0600 (Wed, 23 Dec 2009) $
  */
 
 #ifndef PTLIB_TIMER_H
@@ -81,7 +81,7 @@ class PTimer : public PTimeInterval
   //@{
     /** Create a new timer object and start it in one shot mode for the
        specified amount of time. If the time was zero milliseconds then the
-       timer is {\bf not} started, ie the callback function is not executed
+       timer is {\b not} started, ie the callback function is not executed
        immediately.
       */
     PTimer(
@@ -94,6 +94,9 @@ class PTimer : public PTimeInterval
     PTimer(
       const PTimeInterval & time    ///< New time interval for timer.
     );
+    PTimer(
+      const PTimer & timer    ///< Timer to copy.
+    );
 
     /** Restart the timer in one shot mode using the specified time value. If
        the timer was already running, the "time left" is simply reset.
@@ -107,6 +110,9 @@ class PTimer : public PTimeInterval
     PTimer & operator=(
       const PTimeInterval & time    ///< New time interval for timer.
     );
+    PTimer & operator=(
+      const PTimer & timer          ///< New time interval for timer.
+    );
 
     /** Destroy the timer object, removing it from the applications timer list
        if it was running.
@@ -119,13 +125,13 @@ class PTimer : public PTimeInterval
     /** Set the value of the time interval. The time interval, in milliseconds,
        is the sum of all of the parameters. For example all of the following
        are equivalent:
-\begin{verbatim}
+<code>
               SetInterval(120000)
               SetInterval(60000, 60)
               SetInterval(60000, 0, 1)
               SetInterval(0, 60, 1)
               SetInterval(0, 0, 2)
-\end{verbatim}
+</code>
      */
     virtual void SetInterval(
       PInt64 milliseconds = 0,  ///< Number of milliseconds for interval.
@@ -254,7 +260,20 @@ class PTimer : public PTimeInterval
     static unsigned Resolution();
   //@}
 
-    IDType GetTimerId() const { return timerId; }
+  /**@name Member access */
+  //@{
+    /**Return number of milliseconds left in timer.
+      */
+    PInt64 GetMilliSeconds() const;
+
+    /**Return absolute time timer will expire.
+      */
+    PInt64 GetAbsoluteTime() const { return m_absoluteTime; }
+  //@}
+
+    // Internal functions.
+    IDType GetTimerId() const { return m_timerId; }
+    PAtomicInteger::IntegerType GetNextSerialNumber() { return ++m_serialNumber; }
 
   private:
     void Construct();
@@ -271,28 +290,29 @@ class PTimer : public PTimeInterval
        #PTimerList::Process()# function.
      */
     void Process(
-      const PTimeInterval & delta,    // Time interval since last call.
-      PTimeInterval & minTimeLeft     // Minimum time left till next timeout.
+      PInt64 now             // time consider as "now"
     );
 
-  // Member variables
+    // Member variables
 
     // Callback function for expired timers.
-    PNotifier callback;
+    PNotifier m_callback;
 
     // The time to reset a timer to when RunContinuous() is called.
-    PTimeInterval resetTime;
+    PTimeInterval m_resetTime;
 
     // Timer operates once then stops.
-    PBoolean oneshot;
+    PBoolean m_oneshot;
 
     // Timer state.
-    enum { Stopped, Starting, Running, Paused } state;
+    enum { Stopped, Running, Paused } m_state;
 
     friend class PTimerList;              // needed for Process
-    class PTimerList * timerList;  
+    class PTimerList * m_timerList;  
 
-    IDType timerId;
+    IDType m_timerId;
+    PAtomicInteger m_serialNumber;
+    PInt64 m_absoluteTime;
 
 // Include platform dependent part of class
 #ifdef _WIN32
