@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 23594 $
+ * $Revision: 23110 $
  * $Author: rjongbloed $
- * $Date: 2009-10-06 22:40:27 +0000 (Tue, 06 Oct 2009) $
+ * $Date: 2009-07-17 03:38:54 -0500 (Fri, 17 Jul 2009) $
  */
 
 #ifndef _PMACHDEP_H
@@ -50,7 +50,6 @@
 #include <dlfcn.h>
 
 #define HAS_IFREQ
-#define PSETPGRP()  setpgrp()
 
 #if __GNU_LIBRARY__ < 6
 #define P_LINUX_LIB_OLD
@@ -92,12 +91,6 @@ typedef int socklen_t;
 
 #define HAS_IFREQ
 
-#if defined(__GLIBC__)
-#define PSETPGRP()  setpgrp()
-#else
-#define PSETPGRP()  setpgrp(0, 0)
-#endif
-
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined(P_OPENBSD)
 
@@ -123,8 +116,6 @@ typedef int socklen_t;
 
 #define HAS_IFREQ
 
-#define PSETPGRP()  setpgrp(0, 0)
-
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined(P_NETBSD)
 
@@ -152,8 +143,6 @@ typedef int socklen_t;
 
 #define HAS_IFREQ
 
-#define PSETPGRP()  setpgrp(0, 0)
-
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined(P_SOLARIS)
 
@@ -185,8 +174,6 @@ typedef union {
 } upad128_t;
 #endif
 
-#define PSETPGRP()  setpgrp()
-
 #define INADDR_NONE     -1
 #if P_SOLARIS < 7
 typedef int socklen_t;
@@ -216,7 +203,6 @@ int gethostname(char *, int);
 #include <sys/sockio.h>
 
 #define HAS_IFREQ
-#define PSETPGRP()  setpgrp(0, 0)
 #define raise(s)    kill(getpid(),s)
 
 extern "C" {
@@ -294,7 +280,6 @@ typedef int socklen_t;
 #include <bone/arpa/inet.h>
 
 #define wait3(s, o, r) waitpid(-1, s, o)
-#define PSETPGRP()  setpgid(0,0)
 int seteuid(uid_t euid);
 int setegid(gid_t gid);
 
@@ -348,11 +333,6 @@ typedef int socklen_t;
 #define HAS_IFREQ
 #define _POSIX_MONOTONIC_CLOCK
 
-// hf, 2008-12-25: apparently, earlier versions of 10.5.x needed a version 
-// without parameters. however, something changed such that the 'old' version
-// is required again. (OS X 10.5.6)
-#define PSETPGRP()  setpgrp(0, 0)
-
 
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined (P_AIX)
@@ -379,8 +359,6 @@ typedef int socklen_t;
 
 #define HAS_IFREQ
 
-#define PSETPGRP()  setpgrp()
-
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined (P_IRIX)
 
@@ -407,8 +385,6 @@ typedef int socklen_t;
 
 typedef int socklen_t;
 
-#define PSETPGRP()  setpgrp()
-
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined (P_VXWORKS)
 
@@ -509,7 +485,6 @@ extern "C" {
 #include <netinet/tcp.h>
 
 #define HAS_IFREQ
-#define PSETPGRP()  setpgrp()
 
 ///////////////////////////////////////////////////////////////////////////////
 #elif defined(P_CYGWIN)
@@ -546,6 +521,14 @@ extern "C" {
 
 typedef int SOCKET;
 
+#ifndef PSETPGRP
+#if P_SETPGRP_NOPARM
+#define PSETPGRP()  setpgrp()
+#else
+#define PSETPGRP()  setpgrp(0, 0)
+#endif
+#endif
+
 #ifdef P_PTHREADS
 
 #include <pthread.h>
