@@ -23,9 +23,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22375 $
+ * $Revision: 23956 $
  * $Author: rjongbloed $
- * $Date: 2009-04-06 21:47:23 -0500 (Mon, 06 Apr 2009) $
+ * $Date: 2010-01-21 01:34:45 -0600 (Thu, 21 Jan 2010) $
  */
 
 #ifdef __GNUC__
@@ -246,14 +246,16 @@ PString PHTTPServiceProcess::GetPageGraphic()
   PHTML html(PHTML::InBody);
   html << PHTML::TableStart()
        << PHTML::TableRow()
-       << PHTML::TableData();
+       << PHTML::TableData()
 
+       << PHTML::HotLink("/");
   if (gifHTML.IsEmpty())
     html << PHTML::Heading(1) << productNameHTML << "&nbsp;" << PHTML::Heading(1);
   else
     html << gifHTML;
+  html << PHTML::HotLink()
 
-  html << PHTML::TableData()
+       << PHTML::TableData()
        << GetOSClass() << ' ' << GetOSName()
        << " Version " << GetVersion(PTrue) << PHTML::BreakLine()
        << ' ' << GetCompilationDate().AsString("d MMMM yyyy")
@@ -1638,15 +1640,16 @@ PBoolean PServiceHTML::ProcessMacros(PHTTPRequest & request,
       PCaselessString cmd;
       PString args;
       SplitCmdAndArgs(text, pos, cmd, args);
-      PINDEX idx = ServiceMacros.GetValuesIndex(PServiceMacro(cmd, PTrue));
-      if (idx != P_MAX_INDEX) {
-        PRegularExpression EndBlockRegEx("<?!--#(equival|" + process.GetMacroKeyword() + ")"
-                                         "end[ \t\r\n]+" + cmd + "(-?[^-])*-->?",
-                                         PRegularExpression::Extended|PRegularExpression::IgnoreCase);
-        PINDEX endpos, endlen;
-        if (text.FindRegEx(EndBlockRegEx, endpos, endlen, pos+len)) {
-          PINDEX startpos = pos+len;
-          len = endpos-pos + endlen;
+
+      PRegularExpression EndBlockRegEx("<?!--#(equival|" + process.GetMacroKeyword() + ")"
+                                       "end[ \t\r\n]+" + cmd + "(-?[^-])*-->?",
+                                       PRegularExpression::Extended|PRegularExpression::IgnoreCase);
+      PINDEX endpos, endlen;
+      if (text.FindRegEx(EndBlockRegEx, endpos, endlen, pos+len)) {
+        PINDEX startpos = pos+len;
+        len = endpos-pos + endlen;
+        PINDEX idx = ServiceMacros.GetValuesIndex(PServiceMacro(cmd, PTrue));
+        if (idx != P_MAX_INDEX) {
           substitution = ServiceMacros[idx].Translate(request, args, text(startpos, endpos-1));
           substitedMacro = PTrue;
         }
@@ -1678,6 +1681,25 @@ PBoolean PServiceHTML::ProcessMacros(PHTTPRequest & request,
 }
 
 
+bool PServiceHTML::SpliceMacro(PString & text, const PString & tokens, const PString & value)
+{
+  PString adjustedTokens = tokens;
+  adjustedTokens.Replace(" ", "[ \t\r\n]+");
+  PRegularExpression RegEx("<?!--#" + adjustedTokens + "[ \t\r\n]*-->?",
+                           PRegularExpression::Extended|PRegularExpression::IgnoreCase);
+
+  bool foundOne = false;
+
+  PINDEX pos, len;
+  while (text.FindRegEx(RegEx, pos, len)) {
+    text.Splice(value, pos, len);
+    foundOne = true;
+  }
+
+  return foundOne;
+}
+
+
 ///////////////////////////////////////////////////////////////////
 
 static void ServiceOnLoadedText(PString & text)
