@@ -26,18 +26,24 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21994 $
- * $Author: rjongbloed $
- * $Date: 2009-02-04 16:46:56 -0600 (Wed, 04 Feb 2009) $
+ * $Revision: 23845 $
+ * $Author: shorne $
+ * $Date: 2009-12-07 21:23:45 -0600 (Mon, 07 Dec 2009) $
  */
 
 #include <ptlib.h>
 
-#ifndef _WIN32_WCE
+
+PDEFINE_POOL_ALLOCATOR(PListElement)
+PDEFINE_POOL_ALLOCATOR(PListInfo)
+PDEFINE_POOL_ALLOCATOR(PSortedListElement)
+PDEFINE_POOL_ALLOCATOR(PSortedListInfo)
+PDEFINE_POOL_ALLOCATOR(PHashTableElement)
+
+
 #define new PNEW
 #undef  __CLASS__
 #define __CLASS__ GetClass()
-#endif
 
 
 ///////////////////////////////////////////////////////////////////////////////
@@ -45,7 +51,7 @@
 void PCollection::PrintOn(ostream &strm) const
 {
   char separator = strm.fill();
-  int width = strm.width();
+  int width = (int)strm.width();
   for (PINDEX  i = 0; i < GetSize(); i++) {
     if (i > 0 && separator != ' ')
       strm << separator;
