@@ -7,9 +7,9 @@
  *
  * Contributor(s): Snark at GnomeMeeting
  *
- * $Revision: 20850 $
- * $Author: ms30002000 $
- * $Date: 2008-09-04 16:51:58 +0000 (Thu, 04 Sep 2008) $
+ * $Revision: 22443 $
+ * $Author: rjongbloed $
+ * $Date: 2009-04-20 18:47:22 -0500 (Mon, 20 Apr 2009) $
  */
 
 #include <ptlib.h>
@@ -22,7 +22,7 @@
 
 #ifndef P_DEFAULT_PLUGIN_DIR
 #  if defined (_WIN32_WCE)
-#    define P_DEFAULT_PLUGIN_DIR ".;\\Program Files\\PTLib Plug Ins"
+#    define P_DEFAULT_PLUGIN_DIR "\\Program Files\\PTLib Plug Ins"
 #  elif defined (_WIN32)
 #    define P_DEFAULT_PLUGIN_DIR ".;C:\\Program Files\\PTLib Plug Ins;C:\\PTLIB_PLUGINS;C:\\PWLIB_PLUGINS"
 #  else
@@ -125,7 +125,15 @@ PStringArray PPluginManager::GetPluginDirs()
     env = P_DEFAULT_PLUGIN_DIR + additionalPluginDirs;
 
   // split into directories on correct seperator
-  return env.Tokenise(PATH_SEP, PTrue);
+  PStringArray dirs = env.Tokenise(PATH_SEP, PTrue);
+#ifdef _WIN32_WCE
+  PVarString moduleName;
+  if (GetModuleFileName(GetModuleHandle(NULL), moduleName.GetPointer(1024), 1024) > 0) {
+    PFilePath modulePath = moduleName;
+    dirs.AppendString(modulePath.GetDirectory());
+  }
+#endif // _WIN32
+  return dirs;
 }
 
 PPluginManager & PPluginManager::GetPluginManager()
@@ -499,8 +507,5 @@ void PluginLoaderStartup::OnShutdown()
   }
 }
 
-static PFactory<PProcessStartup>::Worker<PluginLoaderStartup> pluginLoaderStartupFactory("PluginLoader", true);
-
-PINSTANTIATE_FACTORY(PluginLoaderStartup, PString)
-
+PFACTORY_CREATE(PFactory<PProcessStartup>, PluginLoaderStartup, "PluginLoader", true);
 
