@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 22324 $
+ * $Revision: 23292 $
  * $Author: rjongbloed $
- * $Date: 2009-03-30 01:31:45 +0000 (Mon, 30 Mar 2009) $
+ * $Date: 2009-08-28 01:13:05 -0500 (Fri, 28 Aug 2009) $
  */
 
 #include <ptlib.h>
@@ -48,10 +48,7 @@
 #include <ptlib/wm/mmsystemx.h>
 #endif
 
-namespace PWLibStupidLinkerHacks {
-   int loadWindowsMultimediaStuff;
-};
-     
+
 class PSound;
 
 PCREATE_SOUND_PLUGIN(WindowsMultimedia, PSoundChannelWin32);
@@ -935,11 +932,14 @@ PBoolean PSoundChannelWin32::Close()
 
 PBoolean PSoundChannelWin32::SetBuffers(PINDEX size, PINDEX count)
 {
+  if (count == buffers.GetSize() && size == buffers[0].GetSize())
+	  return true;
+
   Abort();
 
   PAssert(size > 0 && count > 0, PInvalidParameter);
 
-  PTRACE(1, "WinSnd\tSetting sounds buffers to " << count << " x " << size);
+  PTRACE(3, "WinSnd\tSetting sounds buffers to " << count << " x " << size);
 
   PBoolean ok = PTrue;
 
@@ -1457,7 +1457,7 @@ PBoolean PSoundChannelWin32::GetVolume(unsigned & oldVolume)
   details.cbDetails = sizeof(volume);
   details.paDetails = &volume;
 
-  MMRESULT result = mixerSetControlDetails((HMIXEROBJ)hMixer, &details, MIXER_OBJECTF_HMIXER | MIXER_GETCONTROLDETAILSF_VALUE);
+  MMRESULT result = mixerGetControlDetails((HMIXEROBJ)hMixer, &details, MIXER_OBJECTF_HMIXER | MIXER_GETCONTROLDETAILSF_VALUE);
   if (result != MMSYSERR_NOERROR)
     return SetErrorValues(Miscellaneous, result|PWIN32ErrorFlag);
 
