@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 21413 $
- * $Author: csoutheren $
- * $Date: 2008-10-27 01:42:43 +0000 (Mon, 27 Oct 2008) $
+ * $Revision: 24000 $
+ * $Author: rjongbloed $
+ * $Date: 2010-01-31 17:57:16 -0600 (Sun, 31 Jan 2010) $
  */
 
 #define _OSUTIL_CXX
@@ -302,21 +302,20 @@ PUInt64 PString::AsUnsigned64(unsigned base) const
 
 
 PTimeInterval PTimer::Tick()
-
 {
-#ifdef P_VXWORKS
+#if defined(_POSIX_MONOTONIC_CLOCK) && !defined(P_MACOSX)
   struct timespec ts;
-  clock_gettime(0,&ts);
-  return (int)(ts.tv_sec*10000) + ts.tv_nsec/100000L;
+  clock_gettime(CLOCK_MONOTONIC, &ts);
+  return ts.tv_sec*1000LL + ts.tv_nsec/1000000LL;
 #else
+  #warning System does not have clock_gettime with CLOCK_MONOTONIC, using gettimeofday
   struct timeval tv;
-  ::gettimeofday (&tv, NULL);
-  return (PInt64)(tv.tv_sec) * 1000 + tv.tv_usec/1000L;
+  gettimeofday(&tv, NULL);
+  return tv.tv_sec*1000LL + tv.tv_usec/1000LL;
 #endif // P_VXWORKS
 }
 
 
-
 ///////////////////////////////////////////////////////////////////////////////
 //
 // PDirectory
