@@ -26,9 +26,9 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Revision: 20385 $
+ * $Revision: 21219 $
  * $Author: rjongbloed $
- * $Date: 2008-06-04 12:40:38 +0200 (mer 04 jun 2008) $
+ * $Date: 2008-10-02 03:52:00 -0500 (Thu, 02 Oct 2008) $
  */
 
 #include <sys/resource.h>
@@ -288,12 +288,6 @@ PProcess::~PProcess()
 
 
 PThread::PThread()
-{
-  // see InitialiseProcessThread()
-}
-
-
-void PThread::InitialiseProcessThread()
 {
   OSStatus err        = 0;
   PX_origStackSize    = 0;
@@ -313,8 +307,18 @@ void PThread::InitialiseProcessThread()
       throw std::bad_alloc();
   }
 
-  ((PProcess *)this)->activeThreads.DisallowDeleteObjects();
-  ((PProcess *)this)->activeThreads.SetAt((unsigned)PX_threadId, this);
+  if (!PProcess::IsInitialised())
+    return;
+
+  autoDelete = true;
+
+  PProcess & process = PProcess::Current();
+
+  process.activeThreadMutex.Wait();
+  process.activeThreads.SetAt(PX_threadId, this);
+  process.activeThreadMutex.Signal();
+
+  process.SignalTimerChange();
 }
 
 
@@ -408,9 +412,9 @@ long PThread::PX_ThreadStart(void * arg)
   PProcess & process = PProcess::Current();
 
   // add thread to thread list
-  process.threadMutex.Wait();
+  process.activeThreadMutex.Wait();
   process.activeThreads.SetAt((unsigned)threadId, thread);
-  process.threadMutex.Signal();
+  process.activeThreadMutex.Signal();
 
   // if we are not supposed to start suspended, then don't wait
   // if we are supposed to start suspended, then wait for a resume
@@ -461,9 +465,9 @@ void PThread::PX_ThreadEnd(void * arg)
   if (id != 0) {
 
     // remove this thread from the active thread list
-    process.threadMutex.Wait();
+    process.activeThreadMutex.Wait();
     process.activeThreads.SetAt((unsigned)id, NULL);
-    process.threadMutex.Signal();
+    process.activeThreadMutex.Signal();
   }
 
   // delete the thread if required, note this is done this way to avoid
@@ -633,16 +637,6 @@ void PThread::Yield()
 }
 
 
-PThread * PThread::Current()
-{
-  PProcess & process = PProcess::Current();
-  process.threadMutex.Wait();
-  PThread * thread = process.activeThreads.GetAt((unsigned)MPCurrentTaskID());
-  process.threadMutex.Signal();
-  return PAssertNULL(thread);
-}
-
-
 void PThread::Sleep(const PTimeInterval & timeout)
 {
     AbsoluteTime expiry;
